# Basi


[![PyPi version][pypi-image]][pypi-link]
[![Supported Python versions][pyversions-image]][pyversions-link]
[![Build status][ci-image]][ci-link]
[![Coverage status][codecov-image]][codecov-link]




## Install

Install from [PyPi](https://pypi.org/project/basi/)

```
pip install basi
```

## Links

- __[Documentation][docs-link]__
- __[API Reference][api-docs-link]__
- __[Get Started][install-link]__
- __[Contributing][contributing-link]__



[docs-link]: https://davidkyalo.github.io/basi/
[api-docs-link]: https://davidkyalo.github.io/basi/
[install-link]: https://davidkyalo.github.io/basi/install.html
[contributing-link]: https://davidkyalo.github.io/basi/contributing.html
[pypi-image]: https://img.shields.io/pypi/v/basi.svg?color=%233d85c6
[pypi-link]: https://pypi.python.org/pypi/basi
[pyversions-image]: https://img.shields.io/pypi/pyversions/basi.svg
[pyversions-link]: https://pypi.python.org/pypi/basi
[ci-image]: https://github.com/davidkyalo/basi/actions/workflows/workflow.yaml/badge.svg?event=push&branch=master
[ci-link]: https://github.com/davidkyalo/basi/actions?query=workflow%3ACI%2FCD+event%3Apush+branch%3Amaster
[codecov-image]: https://codecov.io/gh/davidkyalo/basi/branch/master/graph/badge.svg
[codecov-link]: https://codecov.io/gh/davidkyalo/basi


See this release on GitHub: [v0.5.4](https://github.com/davidkyalo/basi/releases/tag/0.5.4)
